# Estimates of sanctions-induced output losses

# * Specifications with effect of sanctions being captured by s(t-1) -----------

reg.dy1 <- lm(d$ly ~  lag(s,1) + lag(d$ly ,1) + 
                lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1), 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2 <- data.frame(summary(reg.dy1)$adj.r.squared)

lt <- deltaMethod(reg.dy1, "(b1)/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy2 <- lm(d$ly ~  lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) 
              + d$lyw, 
              subset(master, date>="1988Q4"& date<="2019Q4"))
adjr2[2,] <- data.frame(summary(reg.dy2)$adj.r.squared)

lt[2,] <- deltaMethod(reg.dy2, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy3 <- lm(d$ly ~ lag(s,1)+ lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq, 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2[3,] <- data.frame(summary(reg.dy3)$adj.r.squared)

lt[3,] <- deltaMethod(reg.dy3, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy4 <- lm(d$ly ~  lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[4,] <- data.frame(summary(reg.dy4)$adj.r.squared)

lt[4,] <- deltaMethod(reg.dy4, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



reg.dy5 <- lm(d$ly ~  lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr + d$lgep, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[5,] <- data.frame(summary(reg.dy5)$adj.r.squared)

lt[5,] <- deltaMethod(reg.dy5, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



reg.dy6 <- lm(d$ly ~  lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[6,] <- data.frame(summary(reg.dy6)$adj.r.squared)

lt[6,] <- deltaMethod(reg.dy6, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy7 <- lm(d$ly ~  lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve + d$lpoil, 
              subset(master, date>="1988Q4" & date<="2019Q4"))

adjr2[7,] <- data.frame(summary(reg.dy7)$adj.r.squared)
lt[7,] <- deltaMethod(reg.dy7, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



ltcoeff <- paste(sprintf("%.3f",lt$Estimate), "^{**}", sep="", collapse=NULL)
ltse <- paste("(", sprintf("%.3f",lt$SE), ")", sep="", collapse=NULL)


adjr2 <- paste(sprintf("%.3f",adjr2$summary.reg.dy1..adj.r.squared), collapse = NULL)


stargazer(reg.dy1, reg.dy2, reg.dy3, reg.dy4, reg.dy5, reg.dy6, reg.dy7,
          title = "Sanction intensity effect on output.",  
          covariate.labels = c("$s_{t-1} (\\beta_{s_{t-1}})$", 
                               "$\\Delta y_{t-1} (\\lambda_{\\Delta y_{t-1}})$", 
                               "$\\Delta x^{0}_{t-1}$",
                               "$\\Delta e_{f,t-1}$", 
                               "$\\Delta m_{t-1}$", 
                               "$\\Delta p_{t-1}$", 
                               "$\\Delta \\overline{y}_{wt}$",
                               "$\\Delta \\overline{req}_{wt}$",
                               "$\\Delta \\overline{r}_{wt}$",
                               "$\\Delta \\overline{e}_{wt}$",
                               "$grv_{t}$",
                               "$\\Delta p^{0}_{t}$"), 
          omit = c("Constant"), 
          font.size = "small",
          omit.stat = c("all"), 
          no.space = TRUE, 
          column.sep.width = "-15pt" ,
          type = "text",
          dep.var.caption = c("$\\Delta y_{t}$"), 
          align = TRUE, 
          omit.table.layout = "n",
          dep.var.labels.include = FALSE, 
          add.lines = list(c("$\\beta_{s_{t-1}} / (1-\\lambda_{\\Delta y_{t-1}})$", ltcoeff),
                           c("", ltse),
                           c("Adjusted $R^{2}$", adjr2)),          
          out = '../LP Iran Sanctions Results/reduced form equation estimates/DY_LAG1.tex')



rm(list=ls(pattern = "^reg."))
rm(lt, ltcoeff, ltse, adjr2)










# * Specifications with effect of sanctions being captured by s(t) and s(t-1) ------

reg.dy1 <- lm(d$ly ~  s + lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1), 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2 <- data.frame(summary(reg.dy1)$adj.r.squared)

cc <- deltaMethod(reg.dy1, "(b1+b2)", parameterNames= paste("b", 0:2, sep=""))
lt <- deltaMethod(reg.dy1, "(b1+b2)/(1-b3)", parameterNames= paste("b", 0:3, sep=""))


reg.dy2 <- lm(d$ly ~  s + lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) 
              + d$lyw,
              subset(master, date>="1988Q4"& date<="2019Q4"))
adjr2[2,] <- data.frame(summary(reg.dy2)$adj.r.squared)

cc[2,] <- deltaMethod(reg.dy2, "(b1+b2)", parameterNames= paste("b", 0:2, sep=""))
lt[2,] <- deltaMethod(reg.dy2, "(b1+b2)/(1-b3)", parameterNames= paste("b", 0:3, sep=""))



reg.dy3 <- lm(d$ly ~  s + lag(s,1)+ lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq , 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2[3,] <- data.frame(summary(reg.dy3)$adj.r.squared)

cc[3,] <- deltaMethod(reg.dy3, "(b1+b2)", parameterNames= paste("b", 0:2, sep=""))
lt[3,] <- deltaMethod(reg.dy3, "(b1+b2)/(1-b3)", parameterNames= paste("b", 0:3, sep=""))


reg.dy4 <- lm(d$ly ~  s + lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[4,] <- data.frame(summary(reg.dy4)$adj.r.squared)

cc[4,] <- deltaMethod(reg.dy4, "(b1+b2)", parameterNames= paste("b", 0:2, sep=""))
lt[4,] <- deltaMethod(reg.dy4, "(b1+b2)/(1-b3)", parameterNames= paste("b", 0:3, sep=""))



reg.dy5 <- lm(d$ly ~  s + lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr + d$lgep, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[5,] <- data.frame(summary(reg.dy5)$adj.r.squared)

cc[5,] <- deltaMethod(reg.dy5, "(b1+b2)", parameterNames= paste("b", 0:2, sep=""))
lt[5,] <- deltaMethod(reg.dy5, "(b1+b2)/(1-b3)", parameterNames= paste("b", 0:3, sep=""))



reg.dy6 <- lm(d$ly ~  s + lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[6,] <- data.frame(summary(reg.dy6)$adj.r.squared)

cc[6,] <- deltaMethod(reg.dy6, "(b1+b2)", parameterNames= paste("b", 0:2, sep=""))
lt[6,] <- deltaMethod(reg.dy6, "(b1+b2)/(1-b3)", parameterNames= paste("b", 0:3, sep=""))



reg.dy7 <- lm(d$ly ~  s + lag(s,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve + d$lpoil, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[7,] <- data.frame(summary(reg.dy7)$adj.r.squared)

cc[7,] <- deltaMethod(reg.dy7, "(b1+b2)", parameterNames= paste("b", 0:2, sep=""))
lt[7,] <- deltaMethod(reg.dy7, "(b1+b2)/(1-b3)", parameterNames= paste("b", 0:3, sep=""))



jointcoeff <- paste(sprintf("%.3f",cc$Estimate), "^{**}", sep="", collapse=NULL)
jointse <- paste("(", sprintf("%.3f",cc$SE), ")", sep="", collapse=NULL)
ltcoeff <- paste(sprintf("%.3f",lt$Estimate), "^{**}", sep="", collapse=NULL)
ltse <- paste("(", sprintf("%.3f",lt$SE), ")", sep="", collapse=NULL)


adjr2 <- paste(sprintf("%.3f",adjr2$summary.reg.dy1..adj.r.squared), collapse = NULL)


stargazer(reg.dy1, reg.dy2, reg.dy3, reg.dy4, reg.dy5, reg.dy6, reg.dy7,
          title = "Sanction intensity effect on output.",  
          covariate.labels = c("$s_{t} (\\beta_{s_{t}})$", 
                               "$s_{t-1} (\\beta_{s_{t-1}})$", 
                               "$\\Delta y_{t-1} (\\lambda_{\\Delta y_{t-1}})$", 
                               "$\\Delta x^{0}_{t-1}$",
                               "$\\Delta e_{f,t-1}$", 
                               "$\\Delta m_{t-1}$", 
                               "$\\Delta p_{t-1}$", 
                               "$\\Delta \\overline{y}_{wt}$",
                               "$\\Delta \\overline{req}_{wt}$",
                               "$\\Delta \\overline{r}_{wt}$",
                               "$\\Delta \\overline{e}_{wt}$",
                               "$grv_{t}$",
                               "$\\Delta p^{0}_{t}$"),
          omit = c("Constant"), 
          font.size = "small",
          omit.stat = c("all"), 
          no.space = TRUE, 
          column.sep.width = "-15pt" ,
          dep.var.caption = c("$\\Delta y_{t}$"), 
          align = TRUE, 
          type = "text",
          omit.table.layout = "n",
          dep.var.labels.include = FALSE, 
          add.lines = list(c("$\\beta_{s_{t}} + \\beta_{s_{t-1}}$", jointcoeff),
                           c("", jointse),
                           c("$(\\beta_{s_{t}} + \\beta_{s_{t-1}}) / (1-\\lambda_{\\Delta y_{t-1}})$", ltcoeff),
                           c("", ltse),
                           c("Adjusted $R^{2}$", adjr2)),
          out = '../LP Iran Sanctions Results/reduced form equation estimates/DY_LAG_0_1.tex')





rm(list=ls(pattern = "^reg."))
rm(lt, ltcoeff, ltse, jointcoeff, jointse, cc, adjr2)










# * Reduced-form regressions with sanctions dummy variable ---------------------

reg.dy1 <- lm(d$ly ~  lag(s_dummy,1) + lag(d$ly ,1) + 
                lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1), 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2 <- data.frame(summary(reg.dy1)$adj.r.squared)

lt <- deltaMethod(reg.dy1, "(b1)/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy2 <- lm(d$ly ~  lag(s_dummy,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) 
              + d$lyw, 
              subset(master, date>="1988Q4"& date<="2019Q4"))
adjr2[2,] <- data.frame(summary(reg.dy2)$adj.r.squared)

lt[2,] <- deltaMethod(reg.dy2, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy3 <- lm(d$ly ~ lag(s_dummy,1)+ lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq, 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2[3,] <- data.frame(summary(reg.dy3)$adj.r.squared)

lt[3,] <- deltaMethod(reg.dy3, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy4 <- lm(d$ly ~  lag(s_dummy,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[4,] <- data.frame(summary(reg.dy4)$adj.r.squared)

lt[4,] <- deltaMethod(reg.dy4, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



reg.dy5 <- lm(d$ly ~  lag(s_dummy,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr + d$lgep, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[5,] <- data.frame(summary(reg.dy5)$adj.r.squared)

lt[5,] <- deltaMethod(reg.dy5, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



reg.dy6 <- lm(d$ly ~  lag(s_dummy,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[6,] <- data.frame(summary(reg.dy6)$adj.r.squared)

lt[6,] <- deltaMethod(reg.dy6, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy7 <- lm(d$ly ~  lag(s_dummy,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve + d$lpoil, 
              subset(master, date>="1988Q4" & date<="2019Q4"))

adjr2[7,] <- data.frame(summary(reg.dy7)$adj.r.squared)
lt[7,] <- deltaMethod(reg.dy7, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



ltcoeff <- paste(sprintf("%.3f",lt$Estimate), "^{*}", sep="", collapse=NULL)
ltse <- paste("(", sprintf("%.3f",lt$SE), ")", sep="", collapse=NULL)


adjr2 <- paste(sprintf("%.3f",adjr2$summary.reg.dy1..adj.r.squared), collapse = NULL)


stargazer(reg.dy1, reg.dy2, reg.dy3, reg.dy4, reg.dy5, reg.dy6, reg.dy7,
          title = "Sanction intensity effect on output.",  
          covariate.labels = c("$d_{t-1} (\\beta_{d_{t-1}})$", 
                               "$\\Delta y_{t-1} (\\lambda_{\\Delta y_{t-1}})$", 
                               "$\\Delta x^{0}_{t-1}$",
                               "$\\Delta e_{f,t-1}$", 
                               "$\\Delta m_{t-1}$", 
                               "$\\Delta p_{t-1}$", 
                               "$\\Delta \\overline{y}_{wt}$",
                               "$\\Delta \\overline{req}_{wt}$",
                               "$\\Delta \\overline{r}_{wt}$",
                               "$\\Delta \\overline{e}_{wt}$",
                               "$grv_{t}$",
                               "$\\Delta p^{0}_{t}$"), 
          omit = c("Constant"), 
          font.size = "small",
          omit.stat = c("all"), 
          no.space = TRUE, 
          column.sep.width = "-15pt" ,
          type = "text",
          dep.var.caption = c("$\\Delta y_{t}$"), 
          align = TRUE, 
          omit.table.layout = "n",
          dep.var.labels.include = FALSE, 
          add.lines = list(c("$\\beta_{d_{t-1}} / (1-\\lambda_{\\Delta y_{t-1}})$", ltcoeff),
                           c("", ltse),
                           c("Adjusted $R^{2}$", adjr2)),          
          out = '../LP Iran Sanctions Results/reduced form equation estimates/DY_dummy_LAG1.tex')




rm(list=ls(pattern = "^reg."))
rm(lt, ltcoeff, ltse, adjr2)









# * Reduced-form regressions with sanctions discretized variable ---------------

reg.dy1 <- lm(d$ly ~  lag(s_discr,1) + lag(d$ly ,1) + 
                lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1), 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2 <- data.frame(summary(reg.dy1)$adj.r.squared)

lt <- deltaMethod(reg.dy1, "(b1)/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy2 <- lm(d$ly ~  lag(s_discr,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) 
              + d$lyw, 
              subset(master, date>="1988Q4"& date<="2019Q4"))
adjr2[2,] <- data.frame(summary(reg.dy2)$adj.r.squared)

lt[2,] <- deltaMethod(reg.dy2, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy3 <- lm(d$ly ~ lag(s_discr,1)+ lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq, 
              subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2[3,] <- data.frame(summary(reg.dy3)$adj.r.squared)

lt[3,] <- deltaMethod(reg.dy3, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy4 <- lm(d$ly ~  lag(s_discr,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[4,] <- data.frame(summary(reg.dy4)$adj.r.squared)

lt[4,] <- deltaMethod(reg.dy4, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



reg.dy5 <- lm(d$ly ~  lag(s_discr,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1) + 
                d$lyw + d$lgeq + da$data.glr + d$lgep, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[5,] <- data.frame(summary(reg.dy5)$adj.r.squared)

lt[5,] <- deltaMethod(reg.dy5, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



reg.dy6 <- lm(d$ly ~  lag(s_discr,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve, 
              subset(master, date>="1988Q4" & date<="2019Q4"))
adjr2[6,] <- data.frame(summary(reg.dy6)$adj.r.squared)

lt[6,] <- deltaMethod(reg.dy6, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))


reg.dy7 <- lm(d$ly ~  lag(s_discr,1) + lag(d$ly ,1) 
              + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2 ,1) + lag(d$lp ,1)+ 
                d$lyw + d$lgeq + da$data.glr + d$lgep + grve + d$lpoil, 
              subset(master, date>="1988Q4" & date<="2019Q4"))

adjr2[7,] <- data.frame(summary(reg.dy7)$adj.r.squared)
lt[7,] <- deltaMethod(reg.dy7, "b1/(1-b2)", parameterNames= paste("b", 0:3, sep=""))



ltcoeff <- paste(sprintf("%.3f",lt$Estimate), "^{*}", sep="  ", collapse=NULL)
ltse <- paste("(", sprintf("%.3f",lt$SE), ")", sep="", collapse=NULL)


adjr2 <- paste(sprintf("%.3f",adjr2$summary.reg.dy1..adj.r.squared), collapse = NULL)


stargazer(reg.dy1, reg.dy2, reg.dy3, reg.dy4, reg.dy5, reg.dy6, reg.dy7,
          title = "Sanction intensity effect on output.",  
          covariate.labels = c("$s^{D}_{t-1} (\\beta_{s^{D}_{t-1}})$", 
                               "$\\Delta y_{t-1} (\\lambda_{\\Delta y_{t-1}})$", 
                               "$\\Delta x^{0}_{t-1}$",
                               "$\\Delta e_{f,t-1}$", 
                               "$\\Delta m_{t-1}$", 
                               "$\\Delta p_{t-1}$", 
                               "$\\Delta \\overline{y}_{wt}$",
                               "$\\Delta \\overline{req}_{wt}$",
                               "$\\Delta \\overline{r}_{wt}$",
                               "$\\Delta \\overline{e}_{wt}$",
                               "$grv_{t}$",
                               "$\\Delta p^{0}_{t}$"), 
          omit = c("Constant"), 
          font.size = "small",
          omit.stat = c("all"), 
          no.space = TRUE, 
          column.sep.width = "-15pt" ,
          type = "text",
          dep.var.caption = c("$\\Delta y_{t}$"), 
          align = TRUE, 
          omit.table.layout = "n",
          dep.var.labels.include = FALSE, 
          add.lines = list(c("$\\beta_{s^{D}_{t-1}} / (1-\\lambda_{\\Delta y_{t-1}})$", ltcoeff),
                           c("", ltse),
                           c("Adjusted $R^{2}$", adjr2)),          
          out = '../LP Iran Sanctions Results/reduced form equation estimates/DY_sDt_LAG1.tex')




rm(list=ls(pattern = "^reg."))
rm(lt, ltcoeff, ltse, adjr2)

