# SVAR {dxo, dfx, dm2, dp, dy} -------------------------------------------------------------------
# Final model specification. Compact version

svarx.dxo1 <- lm(dxo ~  SR1 + SR2 + SR3 + s + lag(s,1)
                 + lag(dxo,1) + lag(d$lfx_free ,1)  + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                 + d$lyw, 
                 subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2                   <- data.frame(summary(svarx.dxo1)$adj.r.squared)
resid_serial_corr_coeff <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p     <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dfx1 <- lm(d$lfx_free ~  SR1 + SR2 + SR3 + s + lag(s,1) + dxo 
                 + lag(dxo,1) + lag(d$lfx_free ,1)  + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                 + d$lyw,
                 subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[2,]                   <- data.frame(summary(svarx.dfx1)$adj.r.squared)
resid_serial_corr_coeff[2,] <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[2,]     <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)

svarx.dm1 <- lm(dm2 ~  SR1 + SR2 + SR3 + s + lag(s,1) + dxo + d$lfx_free 
                + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + lag(d$lp ,2) + d$lyw, 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[3,]                   <- data.frame(summary(svarx.dm1)$adj.r.squared)
resid_serial_corr_coeff[3,] <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[3,]     <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dp1 <- lm(d$lp ~  SR1 + SR2 + SR3 + s + lag(s,1) + dxo  + d$lfx_free + dm2 
                + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + d$lyw + lag(d$lp ,2), 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[4,]                   <- data.frame(summary(svarx.dp1)$adj.r.squared)
resid_serial_corr_coeff[4,] <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[4,]     <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dy1 <- lm(d$ly ~  SR1 + SR2 + SR3 + s + lag(s,1) + dxo + d$lfx_free + dm2 + d$lp
                + lag(dxo,1) + lag(d$lfx_free, 1) + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                + d$lyw, 
                subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[5,]                   <- data.frame(summary(svarx.dy1)$adj.r.squared)
resid_serial_corr_coeff[5,] <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[5,]     <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


errorsc_coeff <- paste(sprintf("%.3f",resid_serial_corr_coeff$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), collapse = NULL)
errorsc_p <- paste("[", sprintf("%.3f", resid_serial_corr_p$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), "]", sep="", collapse=NULL)
adjr2     <- paste(sprintf("%.3f",adjr2$summary.svarx.dxo1..adj.r.squared), collapse = NULL)
serial    <- paste(errorsc_coeff,"$\\;$ ", errorsc_p)


svarx1<-stargazer(svarx.dxo1, svarx.dfx1, svarx.dm1, svarx.dp1, svarx.dy1,
                  title = "Quarterly estimates of the SVAR model of Iran with seasonally adjusted domestic variables ordered as: oil exports, exchange rate returns, money growth, inflation, and output growth, estimated over the period 1989q1-2019q4",  
                  type = "text",
                  order = c(4:9,16,10:15),
                  covariate.labels = c("$s_{t}$",
                                       "$s_{t-1}$",
                                       "$\\Delta x^{0}_{t}$",
                                       "$\\Delta e_{f,t}$",
                                       "$\\Delta m_{t}$",
                                       "$\\Delta p_{t}$",
                                       "$\\Delta y_{wt}$",
                                       "$\\Delta x^{0}_{t-1}$",
                                       "$\\Delta e_{f,t-1}$",
                                       "$\\Delta m_{t-1}$",
                                       "$\\Delta p_{t-1}$",
                                       "$\\Delta y_{t-1}$",
                                       "$\\Delta p_{t-2}$"),
                  omit = c("Constant", "SR1", "SR2", "SR3"),
                  align = TRUE, 
                  font.size = "small",
                  column.sep.width = "-15pt" ,
                  omit.stat = c("all"), 
                  no.space = TRUE, 
                  dep.var.caption = "",
                  omit.table.layout = "n",
                  add.lines = list(c("Residual serial", errorsc_coeff),
                                   c("correlation test", errorsc_p),
                                   c("Adjusted $R^{2}$", adjr2)),
                  dep.var.labels = c("$\\Delta x^{0}_{t}$",
                                     "$\\Delta e_{f,t}$",
                                     "$\\Delta m_{t}$",
                                     "$\\Delta p_{t}$", 
                                     "$\\Delta y_{t}$"),
                  out = '../LP Iran Sanctions Results/SVAR estimates/svar5_orderDXO.tex')






# SVAR {dxo, dfx, dp, dy} ------------------------------------------------------
# Final model specification. Compact version

svarx.dxo1 <- lm(dxo ~   SR1 + SR2 + SR3 + s + lag(s,1) 
                 + lag(dxo,1) + lag(d$lfx_free ,1) + lag(d$lp ,1) + lag(d$ly ,1)
                 + d$lyw, 
                 subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2                   <- data.frame(summary(svarx.dxo1)$adj.r.squared)
resid_serial_corr_coeff <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p     <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dfx1 <- lm(d$lfx_free ~   SR1 + SR2 + SR3 + s + lag(s,1) + dxo
                 + lag(dxo,1) + lag(d$lfx_free ,1) + lag(d$lp,1) + lag(d$ly,1)
                 + d$lyw,
                 subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[2,]                   <- data.frame(summary(svarx.dfx1)$adj.r.squared)
resid_serial_corr_coeff[2,] <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[2,]     <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)



svarx.dp1 <- lm(d$lp ~   SR1 + SR2 + SR3 + s + lag(s,1) + dxo  + d$lfx_free 
                + lag(dxo ,1) + lag(d$lfx_free ,1)  + lag(d$lp ,1) + lag(d$ly ,1)
                + lag(d$lp ,2) + d$lyw , 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[3,]                   <- data.frame(summary(svarx.dp1)$adj.r.squared)
resid_serial_corr_coeff[3,] <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[3,]     <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dy1 <- lm(d$ly ~   SR1 + SR2 + SR3 + s + lag(s,1) + dxo + d$lfx_free  + d$lp
                + lag(dxo,1) + lag(d$lfx_free, 1) +  lag(d$lp,1) + lag(d$ly,1)
                + d$lyw, 
                subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[4,]                   <- data.frame(summary(svarx.dy1)$adj.r.squared)
resid_serial_corr_coeff[4,] <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[4,]     <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


errorsc_coeff <- paste(sprintf("%.3f",resid_serial_corr_coeff$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), collapse = NULL)
errorsc_p <- paste("[", sprintf("%.3f", resid_serial_corr_p$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), "]", sep="", collapse=NULL)
adjr2     <- paste(sprintf("%.3f",adjr2$summary.svarx.dxo1..adj.r.squared), collapse = NULL)
serial    <- paste(errorsc_coeff,"$\\;$ ", errorsc_p)


svarx1<-stargazer(svarx.dxo1, svarx.dfx1, svarx.dp1, svarx.dy1,
                  title = "Quarterly estimates of the SVAR model of Iran with seasonally adjusted domestic variables ordered as: oil exports,  exchange rate returns, inflation, and output growth, estimated over the period 1989q1-2019q4",  
                  type = "text",
                  order = c(4:8,14,9:13),
                  covariate.labels = c("$s_{t}$",
                                       "$s_{t-1}$",
                                       "$\\Delta x^{0}_{t}$",
                                       "$\\Delta e_{f,t}$",
                                       "$\\Delta p_{t}$",
                                       "$\\Delta y_{wt}$",
                                       "$\\Delta x^{0}_{t-1}$",
                                       "$\\Delta e_{f,t-1}$",
                                       "$\\Delta p_{t-1}$",
                                       "$\\Delta y_{t-1}$",
                                       "$\\Delta p_{t-2}$"),
                  omit = c("Constant", "SR1", "SR2", "SR3"),
                  align = TRUE, 
                  font.size = "small",
                  column.sep.width = "-15pt" ,
                  omit.stat = c("all"), 
                  no.space = TRUE, 
                  dep.var.caption = "",
                  omit.table.layout = "n",
                  add.lines = list(c("Residual serial", errorsc_coeff),
                                   c("correlation test", errorsc_p),
                                   c("Adjusted $R^{2}$", adjr2)),
                  dep.var.labels = c("$\\Delta x^{0}_{t}$",
                                     "$\\Delta e_{f,t}$",
                                     "$\\Delta p_{t}$", 
                                     "$\\Delta y_{t}$"),
                  out = '../LP Iran Sanctions Results/SVAR estimates/svar4_orderDXO_noM2_ADJ.tex')


rm(list = ls(pattern = "^svarx"))
rm(list = ls(pattern = "^error"))
rm(list = ls(pattern = "^res"))
rm(serial)
rm(adjr2)






# SVAR {dxo, dfx, dp, dy} No season dummies  -----------------------------------
# Final model specification. Compact version

svarx.dxo1 <- lm(dxo ~  s + lag(s,1) 
                 + lag(dxo,1) + lag(d$lfx_free ,1) + lag(d$lp ,1) + lag(d$ly ,1)
                 + d$lyw, 
                 subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2                   <- data.frame(summary(svarx.dxo1)$adj.r.squared)
resid_serial_corr_coeff <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p     <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dfx1 <- lm(d$lfx_free ~  s + lag(s,1) + dxo
                 + lag(dxo,1) + lag(d$lfx_free ,1) + lag(d$lp,1) + lag(d$ly,1)
                 + d$lyw,
                 subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[2,]                   <- data.frame(summary(svarx.dfx1)$adj.r.squared)
resid_serial_corr_coeff[2,] <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[2,]     <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)



svarx.dp1 <- lm(d$lp ~  s + lag(s,1) + dxo  + d$lfx_free 
                + lag(dxo ,1) + lag(d$lfx_free ,1)  + lag(d$lp ,1) + lag(d$ly ,1)
                + d$lyw + lag(d$lp ,2), 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[3,]                   <- data.frame(summary(svarx.dp1)$adj.r.squared)
resid_serial_corr_coeff[3,] <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[3,]     <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dy1 <- lm(d$ly ~  s + lag(s,1) + dxo + d$lfx_free  + d$lp
                + lag(dxo,1) + lag(d$lfx_free, 1) +  lag(d$lp,1) + lag(d$ly,1)
                + d$lyw, 
                subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[4,]                   <- data.frame(summary(svarx.dy1)$adj.r.squared)
resid_serial_corr_coeff[4,] <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[4,]     <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


errorsc_coeff <- paste(sprintf("%.3f",resid_serial_corr_coeff$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), collapse = NULL)
errorsc_p <- paste("[", sprintf("%.3f", resid_serial_corr_p$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), "]", sep="", collapse=NULL)
adjr2     <- paste(sprintf("%.3f",adjr2$summary.svarx.dxo1..adj.r.squared), collapse = NULL)
serial    <- paste(errorsc_coeff,"$\\;$ ", errorsc_p)


svarx1<-stargazer(svarx.dxo1, svarx.dfx1, svarx.dp1, svarx.dy1,
                  title = "Quarterly estimates of the SVAR model of Iran with non-seasonally adjusted domestic variables ordered as: oil exports,  exchange rate returns, inflation, and output growth, estimated over the period 1989q1-2019q4",  
                  type = "text",
                  order = c(1:5,10,6:11),
                  covariate.labels = c("$s_{t}$", 
                                       "$s_{t-1}$", 
                                       "$\\Delta x^{0}_{t}$",                                       
                                       "$\\Delta e_{f,t}$",
                                       "$\\Delta p_{t}$",
                                       "$\\Delta y_{wt}$",
                                       "$\\Delta x^{0}_{t-1}$",
                                       "$\\Delta e_{f,t-1}$",
                                       "$\\Delta p_{t-1}$", 
                                       "$\\Delta y_{t-1}$", 
                                       "$\\Delta p_{t-2}$"), 
                  omit = c("Constant"),
                  align = TRUE, 
                  font.size = "small",
                  column.sep.width = "-15pt" ,
                  omit.stat = c("all"), 
                  no.space = TRUE, 
                  dep.var.caption = "",
                  omit.table.layout = "n",
                  add.lines = list(c("Residual serial", errorsc_coeff),
                                   c("correlation test", errorsc_p),
                                   c("Adjusted $R^{2}$", adjr2)),
                  dep.var.labels = c("$\\Delta x^{0}_{t}$",
                                     "$\\Delta e_{f,t}$",
                                     "$\\Delta p_{t}$", 
                                     "$\\Delta y_{t}$"),
                  out = '../LP Iran Sanctions Results/SVAR estimates/svar4_orderDXO_noM2_noADJ.tex')


rm(list = ls(pattern = "^svarx"))
rm(list = ls(pattern = "^error"))
rm(list = ls(pattern = "^res"))
rm(serial)
rm(adjr2)






# SVAR {dxo, dfx, dm2, dp, dy} sanctions dummies -------------------------------
# Final model specification. Compact version

svarx.dxo1 <- lm(dxo ~  SR1 + SR2 + SR3 + s_dummy + lag(s_dummy,1)
                 + lag(dxo,1) + lag(d$lfx_free ,1)  + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                 + d$lyw, 
                 subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2                   <- data.frame(summary(svarx.dxo1)$adj.r.squared)
resid_serial_corr_coeff <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p     <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dfx1 <- lm(d$lfx_free ~  SR1 + SR2 + SR3 + s_dummy + lag(s_dummy,1) + dxo 
                 + lag(dxo,1) + lag(d$lfx_free ,1)  + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                 + d$lyw,
                 subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[2,]                   <- data.frame(summary(svarx.dfx1)$adj.r.squared)
resid_serial_corr_coeff[2,] <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[2,]     <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)

svarx.dm1 <- lm(dm2 ~  SR1 + SR2 + SR3 + s_dummy + lag(s_dummy,1) + dxo + d$lfx_free 
                + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + lag(d$lp ,2) + d$lyw, 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[3,]                   <- data.frame(summary(svarx.dm1)$adj.r.squared)
resid_serial_corr_coeff[3,] <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[3,]     <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dp1 <- lm(d$lp ~  SR1 + SR2 + SR3 + s_dummy + lag(s_dummy,1) + dxo  + d$lfx_free + dm2 
                + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + d$lyw + lag(d$lp ,2), 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[4,]                   <- data.frame(summary(svarx.dp1)$adj.r.squared)
resid_serial_corr_coeff[4,] <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[4,]     <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dy1 <- lm(d$ly ~  SR1 + SR2 + SR3 + s_dummy + lag(s_dummy,1) + dxo + d$lfx_free + dm2 + d$lp
                + lag(dxo,1) + lag(d$lfx_free, 1) + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                + d$lyw, 
                subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[5,]                   <- data.frame(summary(svarx.dy1)$adj.r.squared)
resid_serial_corr_coeff[5,] <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[5,]     <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


errorsc_coeff <- paste(sprintf("%.3f",resid_serial_corr_coeff$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), collapse = NULL)
errorsc_p <- paste("[", sprintf("%.3f", resid_serial_corr_p$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), "]", sep="", collapse=NULL)
adjr2     <- paste(sprintf("%.3f",adjr2$summary.svarx.dxo1..adj.r.squared), collapse = NULL)
serial    <- paste(errorsc_coeff,"$\\;$ ", errorsc_p)


svarx1<-stargazer(svarx.dxo1, svarx.dfx1, svarx.dm1, svarx.dp1, svarx.dy1,
                  title = "Quarterly estimates of the SVAR model of Iran with seasonally adjusted domestic variables ordered as: oil exports, exchange rate returns, money growth, inflation, and output growth, estimated over the period 1989q1-2019q4",  
                  type = "text",
                  order = c(4:9,16,10:15),
                  covariate.labels = c("$d_{t}$",
                                       "$d_{t-1}$",
                                       "$\\Delta x^{0}_{t}$",
                                       "$\\Delta e_{f,t}$",
                                       "$\\Delta m_{t}$",
                                       "$\\Delta p_{t}$",
                                       "$\\Delta y_{wt}$",
                                       "$\\Delta x^{0}_{t-1}$",
                                       "$\\Delta e_{f,t-1}$",
                                       "$\\Delta m_{t-1}$",
                                       "$\\Delta p_{t-1}$",
                                       "$\\Delta y_{t-1}$",
                                       "$\\Delta p_{t-2}$"),
                  omit = c("Constant", "SR1", "SR2", "SR3"),
                  align = TRUE, 
                  font.size = "small",
                  column.sep.width = "-15pt" ,
                  omit.stat = c("all"), 
                  no.space = TRUE, 
                  dep.var.caption = "",
                  omit.table.layout = "n",
                  add.lines = list(c("Residual serial", errorsc_coeff),
                                   c("correlation test", errorsc_p),
                                   c("Adjusted $R^{2}$", adjr2)),
                  dep.var.labels = c("$\\Delta x^{0}_{t}$",
                                     "$\\Delta e_{f,t}$",
                                     "$\\Delta m_{t}$",
                                     "$\\Delta p_{t}$", 
                                     "$\\Delta y_{t}$"),
                  out = '../LP Iran Sanctions Results/SVAR estimates/svar5_Sdummy_orderDXO.tex')



rm(list = ls(pattern = "^svarx"))
rm(list = ls(pattern = "^error"))
rm(list = ls(pattern = "^res"))
rm(serial)
rm(adjr2)






# SVAR {dxo, dfx, dm2, dp, dy} s_t discretized variable ------------------------
# Final model specification. Compact version

svarx.dxo1 <- lm(dxo ~  SR1 + SR2 + SR3 + s_discr + lag(s_discr,1)
                 + lag(dxo,1) + lag(d$lfx_free ,1)  + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                 + d$lyw, 
                 subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2                   <- data.frame(summary(svarx.dxo1)$adj.r.squared)
resid_serial_corr_coeff <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p     <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dfx1 <- lm(d$lfx_free ~  SR1 + SR2 + SR3 + s_discr + lag(s_discr,1) + dxo 
                 + lag(dxo,1) + lag(d$lfx_free ,1)  + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                 + d$lyw,
                 subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[2,]                   <- data.frame(summary(svarx.dfx1)$adj.r.squared)
resid_serial_corr_coeff[2,] <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[2,]     <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)

svarx.dm1 <- lm(dm2 ~  SR1 + SR2 + SR3 + s_discr + lag(s_discr,1) + dxo + d$lfx_free 
                + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + lag(d$lp ,2) + d$lyw, 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[3,]                   <- data.frame(summary(svarx.dm1)$adj.r.squared)
resid_serial_corr_coeff[3,] <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[3,]     <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dp1 <- lm(d$lp ~  SR1 + SR2 + SR3 + s_discr + lag(s_discr,1) + dxo  + d$lfx_free + dm2 
                + lag(dxo ,1) + lag(d$lfx_free ,1) + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + d$lyw + lag(d$lp ,2), 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[4,]                   <- data.frame(summary(svarx.dp1)$adj.r.squared)
resid_serial_corr_coeff[4,] <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[4,]     <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dy1 <- lm(d$ly ~  SR1 + SR2 + SR3 + s_discr + lag(s_discr,1) + dxo + d$lfx_free + dm2 + d$lp
                + lag(dxo,1) + lag(d$lfx_free, 1) + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                + d$lyw, 
                subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[5,]                   <- data.frame(summary(svarx.dy1)$adj.r.squared)
resid_serial_corr_coeff[5,] <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[5,]     <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


errorsc_coeff <- paste(sprintf("%.3f",resid_serial_corr_coeff$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), collapse = NULL)
errorsc_p <- paste("[", sprintf("%.3f", resid_serial_corr_p$bgtest.svarx.dxo1..order...4..order.by...NULL..type...c..Chisq....), "]", sep="", collapse=NULL)
adjr2     <- paste(sprintf("%.3f",adjr2$summary.svarx.dxo1..adj.r.squared), collapse = NULL)
serial    <- paste(errorsc_coeff,"$\\;$ ", errorsc_p)


svarx1<-stargazer(svarx.dxo1, svarx.dfx1, svarx.dm1, svarx.dp1, svarx.dy1,
                  title = "Quarterly estimates of the SVAR model of Iran with seasonally adjusted domestic variables ordered as: oil exports, exchange rate returns, money growth, inflation, and output growth, estimated over the period 1989q1-2019q4",  
                  type = "text",
                  order = c(4:9,16,10:15),
                  covariate.labels = c("$s^{D}_{t}$",
                                       "$s^{D}_{t-1}$",
                                       "$\\Delta x^{0}_{t}$",
                                       "$\\Delta e_{f,t}$",
                                       "$\\Delta m_{t}$",
                                       "$\\Delta p_{t}$",
                                       "$\\Delta y_{wt}$",
                                       "$\\Delta x^{0}_{t-1}$",
                                       "$\\Delta e_{f,t-1}$",
                                       "$\\Delta m_{t-1}$",
                                       "$\\Delta p_{t-1}$",
                                       "$\\Delta y_{t-1}$",
                                       "$\\Delta p_{t-2}$"),
                  omit = c("Constant", "SR1", "SR2", "SR3"),
                  align = TRUE, 
                  font.size = "small",
                  column.sep.width = "-15pt" ,
                  omit.stat = c("all"), 
                  no.space = TRUE, 
                  dep.var.caption = "",
                  omit.table.layout = "n",
                  add.lines = list(c("Residual serial", errorsc_coeff),
                                   c("correlation test", errorsc_p),
                                   c("Adjusted $R^{2}$", adjr2)),
                  dep.var.labels = c("$\\Delta x^{0}_{t}$",
                                     "$\\Delta e_{f,t}$",
                                     "$\\Delta m_{t}$",
                                     "$\\Delta p_{t}$", 
                                     "$\\Delta y_{t}$"),
                  out = '../LP Iran Sanctions Results/SVAR estimates/svar5_Sdiscr_orderDXO.tex')


rm(list = ls(pattern = "^svarx"))
rm(list = ls(pattern = "^error"))
rm(list = ls(pattern = "^res"))
rm(serial)
rm(adjr2)



# SVAR {dfx, dxo, dm2, dp, dy} -------------------------------------------------
# Final model specification. Compact version

svarx.dfx1 <- lm(d$lfx_free ~  SR1 + SR2 + SR3 + s + lag(s,1)
                 + lag(d$lfx_free ,1) + lag(dxo,1) + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                 + d$lyw,
                 subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2                   <- data.frame(summary(svarx.dfx1)$adj.r.squared)
resid_serial_corr_coeff <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p     <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)



svarx.dxo1 <- lm(dxo ~  SR1 + SR2 + SR3 + s + lag(s,1) +  d$lfx_free
                 + lag(d$lfx_free ,1) + lag(dxo,1)  + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                 + d$lyw, 
                 subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2[2,]                   <- data.frame(summary(svarx.dxo1)$adj.r.squared)
resid_serial_corr_coeff[2,] <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[2,]     <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)



svarx.dm1 <- lm(dm2 ~  SR1 + SR2 + SR3 + s + lag(s,1) + d$lfx_free + dxo
                + lag(d$lfx_free ,1) + lag(dxo,1)  + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + lag(d$lp ,2) + d$lyw, 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[3,]                   <- data.frame(summary(svarx.dm1)$adj.r.squared)
resid_serial_corr_coeff[3,] <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[3,]     <- data.frame(bgtest(svarx.dm1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dp1 <- lm(d$lp ~  SR1 + SR2 + SR3 + s + lag(s,1)  + d$lfx_free + dxo + dm2 
                + lag(d$lfx_free ,1) + lag(dxo,1)  + lag(dm2,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + d$lyw + lag(d$lp ,2), 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[4,]                   <- data.frame(summary(svarx.dp1)$adj.r.squared)
resid_serial_corr_coeff[4,] <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[4,]     <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dy1 <- lm(d$ly ~  SR1 + SR2 + SR3 + s + lag(s,1) + d$lfx_free + dxo + dm2 + d$lp
                + lag(d$lfx_free, 1) + lag(dxo,1) + lag(dm2,1) + lag(d$lp,1) + lag(d$ly,1)
                + d$lyw, 
                subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[5,]                   <- data.frame(summary(svarx.dy1)$adj.r.squared)
resid_serial_corr_coeff[5,] <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[5,]     <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


errorsc_coeff <- paste(sprintf("%.3f",resid_serial_corr_coeff$bgtest.svarx.dfx1..order...4..order.by...NULL..type...c..Chisq....), collapse = NULL)
errorsc_p <- paste("[", sprintf("%.3f", resid_serial_corr_p$bgtest.svarx.dfx1..order...4..order.by...NULL..type...c..Chisq....), "]", sep="", collapse=NULL)
adjr2     <- paste(sprintf("%.3f",adjr2$summary.svarx.dfx1..adj.r.squared), collapse = NULL)
serial    <- paste(errorsc_coeff,"$\\;$ ", errorsc_p)


svarx1<-stargazer(svarx.dfx1, svarx.dxo1, svarx.dm1, svarx.dp1, svarx.dy1,
                  title = "Quarterly estimates of the SVAR model of Iran with seasonally adjusted domestic variables ordered as: oil exports, exchange rate returns, money growth, inflation, and output growth, estimated over the period 1989q1-2019q4",  
                  type = "text",
                  order = c(4:9,16,10:15),
                  covariate.labels = c("$s_{t}$",
                                       "$s_{t-1}$",
                                       "$\\Delta e_{f,t}$",                                       
                                       "$\\Delta x^{0}_{t}$",
                                       "$\\Delta m_{t}$",
                                       "$\\Delta p_{t}$",
                                       "$\\Delta y_{wt}$",
                                       "$\\Delta e_{f,t-1}$",
                                       "$\\Delta x^{0}_{t-1}$",                                       
                                       "$\\Delta m_{t-1}$",
                                       "$\\Delta p_{t-1}$",
                                       "$\\Delta y_{t-1}$",
                                       "$\\Delta p_{t-2}$"),
                  omit = c("Constant", "SR1", "SR2", "SR3"),
                  align = TRUE, 
                  font.size = "small",
                  column.sep.width = "-15pt" ,
                  omit.stat = c("all"), 
                  no.space = TRUE, 
                  dep.var.caption = "",
                  omit.table.layout = "n",
                  add.lines = list(c("Residual serial", errorsc_coeff),
                                   c("correlation test", errorsc_p),
                                   c("Adjusted $R^{2}$", adjr2)),
                  dep.var.labels = c("$\\Delta e_{f,t}$",
                                     "$\\Delta x^{0}_{t}$",
                                     "$\\Delta m_{t}$",
                                     "$\\Delta p_{t}$", 
                                     "$\\Delta y_{t}$"),
                  out = '../LP Iran Sanctions Results/SVAR estimates/svar5_orderDFX.tex')






# SVAR {dfx, dxo, dp, dy} ------------------------------------------------------
# Final model specification. Compact version

svarx.dfx1 <- lm(d$lfx_free ~  s + lag(s,1)
                 + lag(d$lfx_free ,1) + lag(dxo,1) + lag(d$lp,1) + lag(d$ly,1)
                 + d$lyw,
                 subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2                   <- data.frame(summary(svarx.dfx1)$adj.r.squared)
resid_serial_corr_coeff <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p     <- data.frame(bgtest(svarx.dfx1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)



svarx.dxo1 <- lm(dxo ~  s + lag(s,1) +  d$lfx_free
                 + lag(d$lfx_free ,1) + lag(dxo,1) + lag(d$lp ,1) + lag(d$ly ,1)
                 + d$lyw, 
                 subset(master, date>="1988Q4" & date<="2019Q4") )
adjr2[2,]                   <- data.frame(summary(svarx.dxo1)$adj.r.squared)
resid_serial_corr_coeff[2,] <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[2,]     <- data.frame(bgtest(svarx.dxo1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)



svarx.dp1 <- lm(d$lp ~  s + lag(s,1)  + d$lfx_free + dxo
                + lag(d$lfx_free ,1) + lag(dxo,1) + lag(d$lp ,1) + lag(d$ly ,1)
                + d$lyw + lag(d$lp ,2), 
                subset(master, date>="1988Q3" & date<="2019Q4") )
adjr2[3,]                   <- data.frame(summary(svarx.dp1)$adj.r.squared)
resid_serial_corr_coeff[3,] <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[3,]     <- data.frame(bgtest(svarx.dp1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


svarx.dy1 <- lm(d$ly ~  s + lag(s,1) + d$lfx_free + dxo + d$lp
                + lag(d$lfx_free, 1) + lag(dxo,1) + lag(d$lp,1) + lag(d$ly,1)
                + d$lyw, 
                subset(master, date >= "1988Q4" & date <= "2019Q4") )
adjr2[4,]                   <- data.frame(summary(svarx.dy1)$adj.r.squared)
resid_serial_corr_coeff[4,] <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$statistic)
resid_serial_corr_p[4,]     <- data.frame(bgtest(svarx.dy1, order = 4, order.by = NULL, type = c("Chisq"), fill = 0)$p.value)


errorsc_coeff <- paste(sprintf("%.3f",resid_serial_corr_coeff$bgtest.svarx.dfx1..order...4..order.by...NULL..type...c..Chisq....), collapse = NULL)
errorsc_p <- paste("[", sprintf("%.3f", resid_serial_corr_p$bgtest.svarx.dfx1..order...4..order.by...NULL..type...c..Chisq....), "]", sep="", collapse=NULL)
adjr2     <- paste(sprintf("%.3f",adjr2$summary.svarx.dfx1..adj.r.squared), collapse = NULL)
serial    <- paste(errorsc_coeff,"$\\;$ ", errorsc_p)


svarx1<-stargazer(svarx.dfx1, svarx.dxo1, svarx.dp1, svarx.dy1,
                  title = "Quarterly estimates of the SVAR model of Iran with seasonally adjusted domestic variables ordered as: oil exports, exchange rate returns, money growth, inflation, and output growth, estimated over the period 1989q1-2019q4",  
                  type = "text",
                  order = c(1:5,10,6:9,11),
                  covariate.labels = c("$s_{t}$",
                                       "$s_{t-1}$",
                                       "$\\Delta e_{f,t}$",
                                       "$\\Delta x^{0}_{t}$",
                                       "$\\Delta p_{t}$",
                                       "$\\Delta y_{wt}$",
                                       "$\\Delta e_{f,t-1}$",
                                       "$\\Delta x^{0}_{t-1}$",
                                       "$\\Delta p_{t-1}$",
                                       "$\\Delta y_{t-1}$",
                                       "$\\Delta p_{t-2}$"),
                  omit = c("Constant"),
                  align = TRUE, 
                  font.size = "small",
                  column.sep.width = "-15pt" ,
                  omit.stat = c("all"), 
                  no.space = TRUE, 
                  dep.var.caption = "",
                  omit.table.layout = "n",
                  add.lines = list(c("Residual serial", errorsc_coeff),
                                   c("correlation test", errorsc_p),
                                   c("Adjusted $R^{2}$", adjr2)),
                  dep.var.labels = c("$\\Delta e_{f,t}$",
                                     "$\\Delta x^{0}_{t}$",
                                     "$\\Delta p_{t}$", 
                                     "$\\Delta y_{t}$"),
                  out = '../LP Iran Sanctions Results/SVAR estimates/svar4_orderDFX.tex')



#* --------
